@@ -8,6 +8,9 @@ git clone https://git.imp.fu-berlin.de/agnumpde/dune-tnnmg.git
 cd dune-matrix-vector
 git apply ../patches/dune-matrix-vector*.diff
 cd ..
+cd dune-tnnmg
+git apply ../patches/dune-tnnmg*.diff
+cd ..
 cd dune-fufem
 git apply ../patches/dune-fufem*.diff
 cd ..
